@@ -1,6 +1,6 @@
 ## ----biocstyle, echo = FALSE, results = "asis", message = FALSE------------
 library(BiocStyle)
-BiocStyle::markdown() 
+BiocStyle::markdown()
 
 ## ----load-libs, warning=FALSE, message=FALSE-------------------------------
 library(EnsDb.Hsapiens.v86)
@@ -12,18 +12,18 @@ edb
 
 ## For what organism was the database generated?
 organism(edb)
- 
+
 
 ## ----no-network, echo = FALSE, results = "hide"----------------------------
 ## Disable code chunks that require network connection - conditionally
 ## disable this on Windows only. This is to avoid TIMEOUT errors on the
 ## Bioconductor Windows build maching (issue #47).
-use_network <- FALSE
- 
+use_network <- TRUE
+
 
 ## ----filters---------------------------------------------------------------
 supportedFilters(edb)
- 
+
 
 ## ----transcripts-----------------------------------------------------------
 Tx <- transcripts(edb, filter = GeneNameFilter("BCL2L11"))
@@ -35,19 +35,19 @@ head(start(Tx))
 
 ## or extract the biotype with
 head(Tx$tx_biotype)
- 
+
 
 ## ----transcripts-filter-expression-----------------------------------------
 ## Use a filter expression to perform the filtering.
 transcripts(edb, filter = ~ gene_name == "ZBTB16")
- 
+
 
 ## ----transcripts-filter, message = FALSE-----------------------------------
 library(magrittr)
 
 edb %>% filter(~ symbol == "BCL2" & tx_biotype != "protein_coding") %>%
     transcripts
- 
+
 
 ## ----filter-Y--------------------------------------------------------------
 edb_y <- addFilter(edb, SeqNameFilter("Y"))
@@ -58,7 +58,7 @@ genes(edb_y)
 
 ## Get all lincRNAs on chromosome Y
 genes(edb_y, filter = ~ gene_biotype == "lincRNA")
- 
+
 
 ## ----list-columns----------------------------------------------------------
 ## list all database tables along with their columns
@@ -66,7 +66,7 @@ listTables(edb)
 
 ## list columns from a specific table
 listColumns(edb, "tx")
- 
+
 
 ## ----transcripts-example2--------------------------------------------------
 Tx <- transcripts(edb,
@@ -75,12 +75,12 @@ Tx <- transcripts(edb,
 		  return.type = "DataFrame")
 nrow(Tx)
 Tx
- 
+
 
 ## ----cdsBy-----------------------------------------------------------------
 yCds <- cdsBy(edb, filter = SeqNameFilter("Y"))
 yCds
- 
+
 
 ## ----genes-GRangesFilter---------------------------------------------------
 ## Define the filter
@@ -93,7 +93,7 @@ gn
 
 ## Next we retrieve all transcripts for that gene so that we can plot them.
 txs <- transcripts(edb, filter = GeneNameFilter(gn$gene_name))
- 
+
 
 ## ----granges-zbtb16, message = FALSE, echo = FALSE-------------------------
 plot(3, 3, pch = NA, xlim = c(start(gn), end(gn)), ylim = c(0, length(txs)),
@@ -107,11 +107,11 @@ for(i in 1:length(txs)) {
          ytop = i-0.125, border = "grey")
     text(start(current), y = i-0.5, pos = 4, cex = 0.75, labels = current$tx_id)
 }
- 
+
 
 ## ----transcripts-GRangesFilter---------------------------------------------
 transcripts(edb, filter = grf)
- 
+
 
 ## ----biotypes--------------------------------------------------------------
 ## Get all gene biotypes from the database. The GeneBiotypeFilter
@@ -120,7 +120,7 @@ listGenebiotypes(edb)
 
 ## Get all transcript biotypes from the database.
 listTxbiotypes(edb)
- 
+
 
 ## ----genes-BCL2------------------------------------------------------------
 ## We're going to fetch all genes which names start with BCL.
@@ -130,7 +130,7 @@ BCLs <- genes(edb,
 	      return.type = "DataFrame")
 nrow(BCLs)
 BCLs
- 
+
 
 ## ----example-AnnotationFilterList------------------------------------------
 ## determine the average length of snRNA, snoRNA and rRNA genes encoded on
@@ -145,7 +145,7 @@ mean(lengthOf(edb, of = "tx",
 mean(lengthOf(edb, of = "tx",
 	      filter = ~ gene_biotype == "protein_coding" &
 		  seq_name %in% c("X", "Y")))
- 
+
 
 ## ----example-first-two-exons-----------------------------------------------
 ## Extract all exons 1 and (if present) 2 for all genes encoded on the
@@ -153,12 +153,12 @@ mean(lengthOf(edb, of = "tx",
 exons(edb, columns = c("tx_id", "exon_idx"),
       filter = list(SeqNameFilter("Y"),
                     ExonRankFilter(3, condition = "<")))
- 
+
 
 ## ----transcriptsBy-X-Y-----------------------------------------------------
 TxByGns <- transcriptsBy(edb, by = "gene", filter = SeqNameFilter(c("X", "Y")))
 TxByGns
- 
+
 
 ## ----exonsBy-RNAseq, message = FALSE, eval = FALSE-------------------------
 #  ## will just get exons for all genes on chromosomes 1 to 22, X and Y.
@@ -182,40 +182,39 @@ TxByGns
 
 ## ----transcript-sequence-AnnotationHub, message = FALSE, eval = FALSE------
 #  library(EnsDb.Hsapiens.v86)
-#  library(Rsamtools)
 #  edb <- EnsDb.Hsapiens.v86
 #  
-#  ## Get the FaFile with the genomic sequence matching the Ensembl version
+#  ## Get the TwoBit with the genomic sequence matching the Ensembl version
 #  ## using the AnnotationHub package.
-#  Dna <- getGenomeFaFile(edb)
+#  dna <- ensembldb:::getGenomeTwoBitFile(edb)
 #  
 #  ## Get start/end coordinates of all genes.
 #  genes <- genes(edb)
 #  ## Subset to all genes that are encoded on chromosomes for which
 #  ## we do have DNA sequence available.
-#  genes <- genes[seqnames(genes) %in% seqnames(seqinfo(Dna))]
+#  genes <- genes[seqnames(genes) %in% seqnames(seqinfo(dna))]
 #  
 #  ## Get the gene sequences, i.e. the sequence including the sequence of
 #  ## all of the gene's exons and introns.
-#  geneSeqs <- getSeq(Dna, genes)
+#  geneSeqs <- getSeq(dna, genes)
 #  
 
 ## ----transcript-sequence-extractTranscriptSeqs, message = FALSE, eval = FALSE----
 #  ## get all exons of all transcripts encoded on chromosome Y
 #  yTx <- exonsBy(edb, filter = SeqNameFilter("Y"))
 #  
-#  ## Retrieve the sequences for these transcripts from the FaFile.
+#  ## Retrieve the sequences for these transcripts from the TwoBitile.
 #  library(GenomicFeatures)
-#  yTxSeqs <- extractTranscriptSeqs(Dna, yTx)
+#  yTxSeqs <- extractTranscriptSeqs(dna, yTx)
 #  yTxSeqs
 #  
 #  ## Extract the sequences of all transcripts encoded on chromosome Y.
-#  yTx <- extractTranscriptSeqs(Dna, edb, filter = SeqNameFilter("Y"))
+#  yTx <- extractTranscriptSeqs(dna, edb, filter = SeqNameFilter("Y"))
 #  
 #  ## Along these lines, we could use the method also to retrieve the coding sequence
 #  ## of all transcripts on the Y chromosome.
 #  cdsY <- cdsBy(edb, filter = SeqNameFilter("Y"))
-#  extractTranscriptSeqs(Dna, cdsY)
+#  extractTranscriptSeqs(dna, cdsY)
 #  
 
 ## ----extractTranscriptSeqs-BSGenome, warning = FALSE, message = FALSE------
@@ -227,17 +226,17 @@ unique(genome(bsg))
 unique(genome(edb))
 
 ## Extract the full transcript sequences.
-yTxSeqs <- extractTranscriptSeqs(bsg, exonsBy(edb, "tx",
-					      filter = SeqNameFilter("Y")))
+yTxSeqs <- extractTranscriptSeqs(
+  bsg, exonsBy(edb, "tx", filter = SeqNameFilter("Y")))
 
 yTxSeqs
 
 ## Extract just the CDS
 Test <- cdsBy(edb, "tx", filter = SeqNameFilter("Y"))
-yTxCds <- extractTranscriptSeqs(bsg, cdsBy(edb, "tx",
-					   filter = SeqNameFilter("Y")))
+yTxCds <- extractTranscriptSeqs(
+  bsg, cdsBy(edb, "tx", filter = SeqNameFilter("Y")))
 yTxCds
- 
+
 
 ## ----seqlevelsStyle, message = FALSE---------------------------------------
 ## Change the seqlevels style form Ensembl (default) to UCSC:
@@ -247,7 +246,7 @@ seqlevelsStyle(edb) <- "UCSC"
 genesY <- genes(edb, filter = ~ seq_name == "chrY")
 ## The seqlevels of the returned GRanges are also in UCSC style
 seqlevels(genesY)
- 
+
 
 ## ----seqlevelsStyle-2, message = FALSE-------------------------------------
 seqlevelsStyle(edb) <- "UCSC"
@@ -265,11 +264,11 @@ seqlevels(edb)[1:30]
 
 ## Resetting the option.
 options(ensembldb.seqnameNotFound = "ORIGINAL")
- 
+
 
 ## ----seqlevelsStyle-restore------------------------------------------------
 seqlevelsStyle(edb) <- "Ensembl"
- 
+
 
 ## ----gviz-plot, message=FALSE----------------------------------------------
 ## Loading the Gviz library
@@ -291,7 +290,7 @@ options(ucscChromosomeNames = FALSE)
 plotTracks(list(gat, GeneRegionTrack(gr)))
 
 options(ucscChromosomeNames = TRUE)
- 
+
 
 ## ----message=FALSE---------------------------------------------------------
 seqlevelsStyle(edb) <- "UCSC"
@@ -302,7 +301,7 @@ seqnames(gr)
 ## Define a genome axis track
 gat <- GenomeAxisTrack()
 plotTracks(list(gat, GeneRegionTrack(gr)))
- 
+
 
 ## ----gviz-separate-tracks, message=FALSE, warning=FALSE--------------------
 protCod <- getGeneRegionTrackForGviz(edb, chromosome = "chrY",
@@ -317,7 +316,7 @@ plotTracks(list(gat, GeneRegionTrack(protCod, name = "protein coding"),
 
 ## At last we change the seqlevels style again to Ensembl
 seqlevelsStyle <- "Ensembl"
- 
+
 
 ## ----pplot-plot, message = FALSE, eval = FALSE-----------------------------
 #  library(ggbio)
@@ -356,7 +355,7 @@ length(gids)
 ## Get all gene names for genes encoded on chromosome Y.
 gnames <- keys(edb, keytype = "GENENAME", filter = SeqNameFilter("Y"))
 head(gnames)
- 
+
 
 ## ----select, message = FALSE, warning=FALSE--------------------------------
 ## Use the /standard/ way to fetch data.
@@ -367,7 +366,7 @@ select(edb, keys = c("BCL2", "BCL2L11"), keytype = "GENENAME",
 select(edb, keys = ~ gene_name %in% c("BCL2", "BCL2L11") &
 		tx_biotype == "protein_coding",
        columns = c("GENEID", "GENENAME", "TXID", "TXBIOTYPE"))
- 
+
 
 ## ----mapIds, message = FALSE-----------------------------------------------
 ## Use the default method, which just returns the first value for multi mappings.
@@ -381,22 +380,22 @@ mapIds(edb, keys = c("BCL2", "BCL2L11"), column = "TXID", keytype = "GENENAME",
 mapIds(edb, keys = list(GeneNameFilter(c("BCL2", "BCL2L11")),
                         TxBiotypeFilter("protein_coding")), column = "TXID",
        multiVals = "list")
- 
+
 
 ## ----AnnotationHub-query, message = FALSE, eval = use_network--------------
-#  library(AnnotationHub)
-#  ## Load the annotation resource.
-#  ah <- AnnotationHub()
-#  
-#  ## Query for all available EnsDb databases
-#  query(ah, "EnsDb")
-#  
+library(AnnotationHub)
+## Load the annotation resource.
+ah <- AnnotationHub()
+
+## Query for all available EnsDb databases
+query(ah, "EnsDb")
+
 
 ## ----AnnotationHub-query-2, message = FALSE, eval = use_network------------
-#  ahDb <- query(ah, pattern = c("Xiphophorus Maculatus", "EnsDb", 87))
-#  ## What have we got
-#  ahDb
-#  
+ahDb <- query(ah, pattern = c("Xiphophorus Maculatus", "EnsDb", 87))
+## What have we got
+ahDb
+
 
 ## ----AnnotationHub-fetch, message = FALSE, eval = FALSE--------------------
 #  ahEdb <- ahDb[[1]]
@@ -441,32 +440,28 @@ mapIds(edb, keys = list(GeneNameFilter(c("BCL2", "BCL2L11")),
 #  edb <- EnsDb(DbFile)
 #  
 #  
-#  ## Identify and get the FaFile object with the genomic DNA sequence matching
+#  ## Identify and get the TwoBit object with the genomic DNA sequence matching
 #  ## the EnsDb annotation.
-#  Dna <- getGenomeFaFile(edb)
-#  library(Rsamtools)
+#  Dna <- getGenomeTwoBitFile(edb)
 #  ## We next retrieve the sequence of all exons on chromosome Y.
 #  exons <- exons(edb, filter = SeqNameFilter("Y"))
 #  exonSeq <- getSeq(Dna, exons)
 #  
-#  ## Alternatively, look up and retrieve the toplevel DNA sequence manually.
-#  Dna <- ah[["AH22042"]]
-#  
 
 ## ----EnsDb-from-Y-GRanges, message = FALSE, eval = use_network-------------
-#  ## Generate a sqlite database from a GRanges object specifying
-#  ## genes encoded on chromosome Y
-#  load(system.file("YGRanges.RData", package = "ensembldb"))
-#  Y
-#  
-#  ## Create the EnsDb database file
-#  DB <- ensDbFromGRanges(Y, path = tempdir(), version = 75,
-#  		       organism = "Homo_sapiens")
-#  
-#  ## Load the database
-#  edb <- EnsDb(DB)
-#  edb
-#  
+## Generate a sqlite database from a GRanges object specifying
+## genes encoded on chromosome Y
+load(system.file("YGRanges.RData", package = "ensembldb"))
+Y
+
+## Create the EnsDb database file
+DB <- ensDbFromGRanges(Y, path = tempdir(), version = 75,
+		       organism = "Homo_sapiens")
+
+## Load the database
+edb <- EnsDb(DB)
+edb
+
 
 ## ----EnsDb-from-GTF, message = FALSE, eval = FALSE-------------------------
 #  library(ensembldb)
@@ -488,5 +483,5 @@ mapIds(edb, keys = list(GeneNameFilter(c("BCL2", "BCL2L11")),
 #  
 
 ## ----sessionInfo-----------------------------------------------------------
-sessionInfo() 
+sessionInfo()
 
